==> percona-server-8.0.15-6.tar.gz: percona-server-8.0.15-6/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/Db.java <==
/*
   Copyright (c) 2010, 2017, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.ClusterJDatastoreException;

/**
 *
 */
public interface Db {

    public void close();

    public Dictionary getDictionary();

    public ClusterTransaction startTransaction(String joinTransactionId);

    public boolean isRetriable(ClusterJDatastoreException ex);

    public void assertNotClosed(String where);
}

==> percona-server_8.0.41-32.orig.tar.gz: percona-server-8.0.41-32/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/Db.java <==
/*
   Copyright (c) 2010, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.ClusterJDatastoreException;

/**
 *
 */
public interface Db {

    public void close();

    public Dictionary getDictionary();

    public ClusterTransaction startTransaction();

    public boolean isRetriable(ClusterJDatastoreException ex);

    public void assertNotClosed(String where);
}
